@@ -27,25 +27,23 @@
 #include "backtracegenerator.h"
 #include "backtraceparser.h"
 #include "backtracewidget.h"
+#include "bugzillaintegration/bugzillalib.h"
 #include "config-drkonqi.h"
 #include "crashedapplication.h"
 #include "debuggerlaunchers.h"
 #include "debuggermanager.h"
 #include "drkonqi.h"
 #include "drkonqi_globals.h"
-#include "qmlextensions/commentmodel.h"
 #include "qmlextensions/credentialstore.h"
 #include "qmlextensions/doctore.h"
-#include "qmlextensions/duplicatemodel.h"
 #include "qmlextensions/platformmodel.h"
 #include "qmlextensions/reproducibilitymodel.h"
 #include "settings.h"
-#include "systeminformation.h"
 
 static const QString ABOUT_BUG_REPORTING_URL = QStringLiteral("https://community.kde.org/Get_Involved/Issue_Reporting");
 static const QString DRKONQI_REPORT_BUG_URL = KDE_BUGZILLA_URL + QStringLiteral("enter_bug.cgi?product=drkonqi&format=guided");
 
-void DrKonqiDialog::show()
+void DrKonqiDialog::show(DrKonqiDialog::GoTo to)
 {
     if (DrKonqi::isSafer() || DrKonqi::minimalMode()) {
         QDialog::show();
@@ -59,7 +57,6 @@ void DrKonqiDialog::show()
     engine->rootContext()->setContextObject(l10nContext);
 
     qmlRegisterType<BugzillaManager>("org.kde.drkonqi", 1, 0, "Bugzilla");
-    qmlRegisterType<DuplicateModel>("org.kde.drkonqi", 1, 0, "DuplicateModel");
     qmlRegisterType<PlatformModel>("org.kde.drkonqi", 1, 0, "PlatformModel");
     qmlRegisterType<ReproducibilityModel>("org.kde.drkonqi", 1, 0, "ReproducibilityModel");
     qmlRegisterType<CredentialStore>("org.kde.drkonqi", 1, 0, "CredentialStore");
@@ -84,10 +81,19 @@ void DrKonqiDialog::show()
         engine,
         &QQmlApplicationEngine::objectCreated,
         this,
-        [mainUrl, this](QObject *obj, const QUrl &objUrl) {
+        [mainUrl, this, to](QObject *obj, const QUrl &objUrl) {
             if (!obj && mainUrl == objUrl) {
                 qWarning() << "Failed to load QML dialog, falling back to QWidget.";
                 QDialog::show();
+                return;
+            }
+
+            switch (to) {
+            case GoTo::Main:
+                break;
+            case GoTo::Sentry:
+                QMetaObject::invokeMethod(obj, "goToSentry", Qt::QueuedConnection);
+                break;
             }
         },
         Qt::QueuedConnection);
@@ -115,7 +121,7 @@ DrKonqiDialog::DrKonqiDialog(QWidget *parent)
 
     connect(m_tabWidget, &QTabWidget::currentChanged, this, &DrKonqiDialog::tabIndexChanged);
 
-    KConfigGroup config(KSharedConfig::openConfig(), "General");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
 
     if (!config.readEntry(QStringLiteral("ShowOnlyBacktrace"), false)) {
         buildIntroWidget();
@@ -139,7 +145,7 @@ DrKonqiDialog::DrKonqiDialog(QWidget *parent)
 
 DrKonqiDialog::~DrKonqiDialog()
 {
-    KConfigGroup config(KSharedConfig::openConfig(), "General");
+    KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General"));
     KWindowConfig::saveWindowSize(windowHandle(), config);
 }
 
@@ -220,16 +226,9 @@ void DrKonqiDialog::buildIntroWidget()
                                     // prevent number localization by ki18n
                                     QString::number(crashedApp->pid()),
                                     crashedApp->signalName(),
-#if defined(Q_OS_UNIX)
                                     // prevent number localization by ki18n
                                     QString::number(crashedApp->signalNumber()),
-#else
-                                    // windows uses weird big numbers for exception codes,
-                                    // so it doesn't make sense to display them in decimal
-                                    QString().asprintf("0x%8x", crashedApp->signalNumber()),
-#endif
                                     locale.toString(crashedApp->datetime().date(), QLocale::ShortFormat),
-
                                     locale.toString(crashedApp->datetime().time())));
 }
 
